pub fn build_ptdf_lodf_with_options(
case: &IndexedNetwork<'_>,
options: &SensitivityOptions,
) -> Result<SensitivityMatrices>Expand description
PTDF and LODF with solver selection, drop tolerance, and output metadata.
pub fn build_ptdf_lodf_with_options(
case: &IndexedNetwork<'_>,
options: &SensitivityOptions,
) -> Result<SensitivityMatrices>PTDF and LODF with solver selection, drop tolerance, and output metadata.